#[non_exhaustive]pub struct ConnectionFailureContext {
pub connection_id: u64,
pub direction: Option<ConnectionDirection>,
pub method: Option<String>,
pub request_id: Option<ConnectionRequestId>,
}Expand description
Non-sensitive identity attached to a connection failure when available.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_id: u64Monotonic process-local identity of the affected connection.
direction: Option<ConnectionDirection>Traffic direction, when the failure belongs to one side of the wire.
method: Option<String>Framework-owned, registered, or locally declared typed outbound method, when known without trusting an unvalidated peer-controlled method name.
request_id: Option<ConnectionRequestId>JSON-RPC request ID, when the event belongs to a request.